import argparse
import sys
from pathlib import Path

from hairy_hashes.hashes import rm_duplicate_hashes


def main() -> None:
    """Remove files with duplicate SHA256 hashes."""
    try:
        parser = argparse.ArgumentParser(
            description="Remove files with duplicate SHA256 hashes.",
            formatter_class=argparse.MetavarTypeHelpFormatter,
        )

        parser.add_argument(
            "file",
            type=Path,
            nargs="+",
            help="file to compare",
        )
        parser.add_argument(
            "-d",
            "--date",
            action="store_true",
            help="choose remaining copy by most recently modified "
            "(default: choose by filename)",
        )
        parser.add_argument(
            "-r",
            "--reverse",
            action="store_true",
            help="reverse selection process",
        )

        args = parser.parse_args()

        rm_duplicate_hashes(args.file, args.date, args.reverse)

    except Exception as e:
        print(str(e))
        sys.exit(2)


if __name__ == "__main__":
    main()
